@@ -23,28 +23,17 @@ static uint32_t pcg32_random_r(pcg32_random_t* rng) {
 ///////////////////////////////////////////////////////////////////////////
 
 pcg32_random_t one;
-pcg32_random_t two;
 
 static void _seed(uint64_t seed1, uint64_t seed2) {
 	one.state = seed1;
 	one.inc   = seed2;
 
 	//printf("One: %lu / %lu\n", one.state, one.inc);
-
-	// The second PRNG is only used when we generate
-	// 64 bit integers. We use the seeds for the first
-	// PRNG XORd with nanoseconds to mix them up a
-	// little bit. This should NOT be predictable in
-	// any easy way
-	two.state = seed1 ^ nanos();
-	two.inc   = seed2 ^ nanos();
-
-	//printf("Two: %lu / %lu\n", two.state, two.inc);
 }
 
 static uint64_t _rand64() {
 	uint64_t high = pcg32_random_r(&one);
-	uint32_t low  = pcg32_random_r(&two);
+	uint32_t low  = pcg32_random_r(&one);
 
 	uint64_t ret = (high << 32) | low;
 
